#
# spec file for package pv
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pv
Version:        1.6.0
Release:        30.1
Summary:        PipeViewer - Monitor the Progress of Data through Pipes
License:        Artistic-2.0
Group:          System/Base
Url:            http://ivarch.com/programs/pv.shtml

Source:         http://ivarch.com/programs/sources/%name-%version.tar.bz2
Source2:        http://ivarch.com/programs/sources/%name-%version.tar.bz2.txt
Source3:        %name.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  gettext-devel
BuildRequires:  glibc-devel
BuildRequires:  intltool
BuildRequires:  make
%if 0%{?suse_version} && 0%{?suse_version} <= 1200
# The testsuite wants the "usleep" utility
BuildRequires:  sysvinit
%else
BuildRequires:  sysvinit-tools
%endif

%description
PV ("Pipe Viewer") is a tool for monitoring the progress of data through a
pipeline.  It can be inserted into any normal pipeline between two processes
to give a visual indication of how quickly data is passing through, how long
it has taken, how near to completion it is, and an estimate of how long it
will be until completion.

%prep
%setup -q

%build
%configure \
	--enable-lfs \
	--enable-nls \
	--disable-debugging

make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
%find_lang "%{name}"

%check
make test

%files -f %name.lang
%defattr(-,root,root)
%doc README doc/COPYING doc/NEWS doc/TODO
%_bindir/pv
%doc %_mandir/man1/pv.1%ext_man

%changelog
* Fri Mar 27 2015 jengelh@inai.de
- Update to new upstream release 1.6.0
  * new option "-D" / "--delay-start" to only show bar after
  N seconds
  * new option "--fineta" / "-I" to show ETA as time of day rather
  than time remaining
  * change ETA (--eta / -e) so that days are given if the hours
  remaining are 24 or more
  * repeat read and write attempts on partial buffer fill/empty to
  work around post-signal transfer rate drop
  * output errors on a new line to avoid overwriting transfer bar
* Mon Dec  8 2014 jengelh@inai.de
- Update to new upstream release 1.5.7
  * show KiB instead of incorrect kiB
  * work around awk bug in tests/016-numeric-timer in decimal ","
  locales
* Mon May  5 2014 jengelh@inai.de
- Update to new upstream release 1.5.3
  * Added new display options --buffer-percent, --last-written
  * New transfer option --no-splice
  * New option --watchfd to monitor file descriptor status of another
  process, rather than moving data from stdin to stdout.
* Mon Aug 12 2013 jengelh@inai.de
- Update to new upstream release 1.4.12
  * A fix for splice() not using stdin was implemented
  * A new -0/--null option has been added to count NUL-terminated
  "lines"
* Wed Jun  5 2013 jengelh@inai.de
- Add explicit BuildRequires for usleep
* Fri Jan 25 2013 jengelh@inai.de
- Update to new upstream release 1.4.6
  * updated manual page to show known problem with "-R" on Cygwin
  * added patch from Pawel Piatek to omit O_NOFOLLOW in AIX
* Mon Dec 24 2012 jengelh@inai.de
- Update to new upstream release 1.4.4
  * fix crash when progress is displayed with too-small terminal
  * new option --skip-errors
  * new option --stop-at-size to stop after --size bytes
  * autodetermine size if stdout is a block device
  * fix a use-after-free bug
* Tue Nov 20 2012 jengelh@inai.de
- Update to new upstream release 1.3.9
  * new --pidfile option to save process ID to a file
  * integrated patch for --numeric with --timer and --bytes
  * removed signalling from --remote to prevent accidental process kills
  * new --format option and allow --format parameters to be sent
  with --remote
* Sat Sep  1 2012 jengelh@inai.de
- Update to new upstream release 1.3.4
  * new --disable-splice configure script option
  * fixed line mode size count with multiple files
- Use RH-friendly make install
* Mon Jun 25 2012 pascal.bleser@opensuse.org
- update to 1.3.1:
  * do not use splice() if the write buffer is not empty
- changes from 1.3.0:
  * fix 1024-boundary display garble
  * use splice(2) where available
  * added known bugs section of the manual page
  * use IEEE1541 units
  * bug with rate limit under 10 fixed
  * speed up PV line mode
* Tue May 22 2012 jengelh@inai.de
- Feed through format_spec_file to get copyright header required
  for factory inclusion
* Mon Feb 20 2012 jengelh@medozas.de
- Update license field to SPDX format
- Use short URL
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Fri Jan 14 2011 pascal.bleser@opensuse.org
- change RPM group to System/Base instead of invalid group System/Tools
* Tue Dec 14 2010 pascal.bleser@opensuse.org
- update to 1.2.0:
  * an average rate display option was added to better show progress with bursty traffic
  * a consistent exit status is set to help script writers
  * various minor cleanups and bug fixes were made
* Tue Nov  9 2010 pascal.bleser@opensuse.org
- moved to utilities
* Thu Mar  6 2008 guru@unixtech.be
- new upstream version
* Mon Oct 22 2007 guru@unixtech.be
- moved to openSUSE Build Service
* Thu Aug 30 2007 guru@unixtech.be
- new upstream version
* Fri Aug  3 2007 guru@unixtech.be
- new upstream version
* Mon Feb  5 2007 guru@unixtech.be
- new upstream version
* Tue Feb 28 2006 guru@unixtech.be
- new upstream version
* Thu Dec  8 2005 guru@unixtech.be
- added debuginfo support
- use makeinstall macro
- use configure macro
- added autoreconf
- use install_info SUSE macros
- use find_lang macro
- rewrote spec file
- new upstream version
* Fri Jun 17 2005 guru@unixtech.be
- version 0.9.1
* Sun Nov  7 2004 guru@unixtech.be
- version 0.8.9
* Mon May  3 2004 guru@unixtech.be
- version 0.8.5
* Sun Apr 25 2004 guru@unixtech.be
- version 0.8.2
* Tue Apr 20 2004 guru@unixtech.be
- version 0.8.1
* Sun Feb  8 2004 guru@unixtech.be
- version 0.7.0
* Tue Jan  6 2004 guru@unixtech.be
- new spec-file
